@@ -508,11 +508,54 @@ public:
 	 * Get the last (most recently set) value for a given keyword.
 	 * This is typically the value actually used.
 	 *
-	 * @param sym keywork symbol name.
+	 * @param sym keyword symbol name.
 	 * @return last set value for this symbol.
 	 */
 	const char* getLast(const char *sym);
 
+	/**
+	 * Find if a given key exists.
+	 *
+	 * @param sym keyword to find.
+	 * @return true if exists.
+	 */
+	bool isKey(const char *sym);
+
+	/**
+	 * Get a string value, with an optional default if missing.
+	 *
+	 * @param sym keyword name.
+	 * @param default if not present.
+	 * @return string value of key.
+	 */
+	const char *getString(const char *sym, const char *def = NULL);
+
+	/**
+	 * Get a long value, with an optional default if missing.
+	 *
+	 * @param sym keyword name.
+	 * @param default if not present.
+	 * @return long value of key.
+	 */
+	long getLong(const char *sym, long def = 0);
+
+	/**
+	 * Get a bool value.
+	 *
+	 * @param sym keyword name.
+	 * @return true or false.
+	 */
+	bool getBool(const char *key);
+
+	/**
+	 * Get a floating value.
+	 *
+	 * @param sym keyword name.
+	 * @param default if not set.
+	 * @return value of key.
+	 */
+	double getDouble(const char *key, double def = 0.); 
+
 	/**
 	 * Get an index array of ALL keywords that are stored by the
 	 * current keydata object.
