@@ -215,6 +215,8 @@ private:
 public:
 	/**
 	 * The mutex is always initialized as a recursive entity.
+	 *
+	 * @param name of mutex for optional deadlock detection
 	 */
 	Mutex(const char *name = NULL);
 
@@ -238,8 +240,8 @@ public:
 	 *
 	 * @param name for mutex.
 	 */
-	inline void nameMutex(const char *cp)
-		{_name = cp;};
+	inline void nameMutex(const char *name)
+		{_name = name;};
 
 	/**
 	 * Entering a Mutex locks the mutex for the current thread.  This
@@ -256,9 +258,17 @@ public:
 	inline void enter(void)
 		{enterMutex();};
 
+        /**
+         * Future abi will use enter/leave/test members.
+         */
 	inline void leave(void)
 		{leaveMutex();};
 
+        /**
+         * Future abi will use enter/leave/test members.
+	 *
+	 * @return true if entered.
+         */
 	inline bool test(void)
 		{return tryEnterMutex();};
 
@@ -317,9 +327,12 @@ private:
 public:
 	/**
 	 * Acquire the mutex
+	 *
+	 * @param _mutex reference to mutex to aquire.
 	 */
 	MutexLock( Mutex& _mutex ) : mutex( _mutex ) 
 		{ mutex.enterMutex(); }
+
 	/**
 	 * Release the mutex automatically
 	 */
@@ -414,6 +427,8 @@ private:
 public:
 	/**
 	 * Wait for read access
+	 *
+	 * @param _tl reference to lock to aquire.
 	 */
 	ReadLock( ThreadLock& _tl ) : tl( _tl ) 
 		{ tl.readLock(); }
@@ -452,7 +467,9 @@ private:
 
 public:
 	/**
-	 * Wait for read access
+	 * Wait for write access
+	 *
+	 * @param _tl reference to threadlock to aquire.
 	 */
 	WriteLock( ThreadLock& _tl ) : tl( _tl ) 
 		{ tl.writeLock(); }
@@ -480,7 +497,20 @@ private:
 	volatile int	counter;
 
 public:
+	/**
+	 * Create and optionally name a mutex protected counter.
+	 *
+	 * @param id name for mutex counter, optional for deadlock testing.
+	 */
 	MutexCounter(const char *id = NULL);
+
+	/**
+	 * Create and optionally name a mutex protected counter with
+	 * an initial value.
+	 *
+	 * @param initial value of counter.
+	 * @param id name of counter, optional for deadlock testing.
+	 */
 	MutexCounter(int initial, const char *id = NULL);
 
 	friend __EXPORT int operator++(MutexCounter &mc);
@@ -607,6 +637,8 @@ private:
 public:
 	/**
 	 * Create an instance of a conditional.
+	 *
+	 * @param id name of conditional, optional for deadlock testing.
 	 */
 	Conditional(const char *id = NULL);
 
@@ -1460,7 +1492,7 @@ public:
 	/**
 	 * This is used to restore a cancel block.	
 	 *
-	 * @param saved cancel type.
+	 * @param cancel type that was saved.
 	 */
 	static void exitCancel(Cancel cancel);
 };
