@@ -39,6 +39,7 @@
 #include <cc++/export.h>
 #include <cc++/thread.h>
 #include <cc++/exception.h>
+#include <cc++/process.h>
 #ifdef	__BORLANDC__
 #include <stdio.h>
 #else
@@ -583,6 +584,9 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 	if(pri < -2)
 		pri = -2;
 
+	if(Process::isRealtime() && pri < 0)
+		pri = 0;
+
 	switch(pri)
 	{
 	case 1:
@@ -648,6 +652,9 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 #ifdef	_POSIX_THREAD_PRIORITY_SCHEDULING
 #ifdef HAVE_SCHED_GETSCHEDULER
 #define	__HAS_PRIORITY_SCHEDULING__	
+	if(pri < 0 && Process::isRealtime())
+		pri = 0;
+
 	if(pri)
 	{
 		struct sched_param sched;
