@@ -129,7 +129,7 @@ char **URLStream::extraHeader(void)
 
 int URLStream::underflow(void)
 {
-	ssize_t len, rlen;
+	ssize_t len = 0, rlen;
 	char *buf;
 
 	if(bufsize == 1)
@@ -201,6 +201,10 @@ void URLStream::setProxy(const char *host, tpport_t port)
 #endif
 	case IPV4:
 		proxyHost = host;
+		break;
+	default:
+		proxyPort = 0;
+		return;
 	}
 	proxyPort = port;
 }
@@ -399,12 +403,7 @@ URLStream::Error URLStream::get(const char *urlpath, size_t buf)
 		Socket::state = STREAM;
 		allocate(buf);
 		return errSuccess;
-	case methodHttpPut:
-	case methodHttpPost:
-	case methodHttpPostMultipart:
-	case methodFtpGet:
-	case methodFtpPut:
-	case methodFilePut:
+	default:
     	        break;
 	}
 
@@ -684,6 +683,7 @@ retry:
 		case methodHttpPostMultipart:
 			while(*args)
 				str << *(args++) << "\r\n";
+		default:
 			break;
 		}
 
@@ -727,7 +727,7 @@ retry:
 
 			break;
 #endif
-		default:
+		case IPV4:
 			sockaddr_in source;
 			int alen = sizeof(source);
 
@@ -761,8 +761,9 @@ retry:
 			connect(v6proxyHost, proxyPort, (unsigned)buf);
 			break;
 #endif
-		default:	
+		case IPV4:	
 		        connect(proxyHost, proxyPort, (unsigned)buf);
+			break;
 		}
 	}
 	else
@@ -774,7 +775,7 @@ retry:
 			connect(IPV6Host(hp), port, (unsigned)buf);
 			break;
 #endif
-		default:
+		case IPV4:
 			connect(IPV4Host(hp), port, (unsigned)buf);
 		}
 	}
